@@ -1,7 +1,8 @@
 #' Circular cross-section using the Gauckler-Manning-Strickler equation
 #'
 #' Manningcirc and Manningcircy solve for a missing variable for a circular
-#' cross-section.
+#' cross-section. The \code{\link[stats]{uniroot}} function is used to obtain the
+#' missing parameter.
 #'
 #' The Manningcirc function solves for one missing variable in the Gauckler-
 #' Manning equation for a circular cross-section and uniform flow. The
@@ -70,8 +71,6 @@
 #' }
 #'
 #'
-#'
-#'
 #' \deqn{\theta = 2 \arcsin\left[1 - 2\left(\frac{y}{d}\right)\right]}
 #' \describe{
 #'	\item{\emph{\eqn{\theta}}}{see the equation defining this parameter}
@@ -119,13 +118,22 @@
 #'
 #'
 #'
+#' \deqn{D = \frac{A}{B}}
+#'
+#' \describe{
+#'	\item{\emph{D}}{the hydraulic depth (m or ft)}
+#'	\item{\emph{A}}{the cross-sectional area (m^2 or ft^2)}
+#'	\item{\emph{B}}{the top width of the channel (m or ft)}
+#' }
+#'
+#'
 #' A rough turbulent zone check is performed on the water flowing in the
 #' channel using the Reynolds number (Re). The Re equation follows:
 #'
 #' \deqn{Re = \frac{\rho RV}{\mu}}
 #'
 #' \describe{
-#'	\item{\emph{Re}}{the velocity (m/s or ft/s)}
+#'	\item{\emph{Re}}{Reynolds number (dimensionless)}
 #'	\item{\emph{\eqn{\rho}}}{density (kg/m^3 or slug/ft^3)}
 #'	\item{\emph{R}}{the hydraulic radius (m or ft)}
 #'	\item{\emph{V}}{the velocity (m/s or ft/s)}
@@ -134,6 +142,20 @@
 #'
 #'
 #'
+#' A critical flow check is performed on the water flowing in the channel
+#' using the Froude number (Fr). The Fr equation follows:
+#'
+#' \deqn{Fr = \frac{V}{\left(\sqrt{g * D}\right)}}
+#'
+#' \describe{
+#'	\item{\emph{Fr}}{the Froude number (dimensionless)}
+#'	\item{\emph{V}}{the velocity (m/s or ft/s)}
+#'	\item{\emph{g}}{gravitational acceleration (m/s^2 or ft/sec^2)}
+#'	\item{\emph{D}}{the hydraulic depth (m or ft)}
+#' }
+#'
+#'
+#'
 #' @note
 #' Assumptions: uniform flow, prismatic channel, and surface water temperature
 #' of 20 degrees Celsius (68 degrees Fahrenheit) at atmospheric pressure
@@ -163,12 +185,13 @@
 #'   the United Kingdom)]
 #'
 #' @return the missing parameter (Q, n, or Sf) & theta, area (A), wetted
-#'   perimeter (P), top width (B), velocity (V), R (hydraulic radius), and Re
-#'   (Reynolds number) as a \code{\link[base]{list}} for the Manningcirc function.
-#'   
+#'   perimeter (P), top width (B), velocity (V), R (hydraulic radius), Re
+#'   (Reynolds number), and Fr (Froude number) as a \code{\link[base]{list}} for the
+#'   Manningcirc function.
+#'
 #' @return the missing parameter (d or y) & theta, area (A), wetted
-#'   perimeter (P), top width (B), velocity (V), R (hydraulic radius), and Re
-#'   (Reynolds number) as a \code{\link[base]{list}} for the Manningcircy function.
+#'   perimeter (P), top width (B), velocity (V), and R (hydraulic radius) as a
+#'   \code{\link[base]{list}} for the Manningcircy function.
 #'
 #'
 #' @source
@@ -177,13 +200,16 @@
 #'
 #' @references
 #' \enumerate{
-#'    \item Terry W. Sturm, \emph{Open Channel Hydraulics}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2010, page 8, 36, 102, 120, 123-125, 153-154.
+#'    \item Terry W. Sturm, \emph{Open Channel Hydraulics}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2010, page 2, 8, 36, 102, 120, 123-125, 153-154.
 #'    \item Dan Moore, P.E., NRCS Water Quality and Quantity Technology Development Team, Portland Oregon, "Using Mannings Equation with Natural Streams", August 2011, \url{http://www.wcc.nrcs.usda.gov/ftpref/wntsc/H&H/xsec/manningsNaturally.pdf}.
 #'    \item Gilberto E. Urroz, Utah State University Civil and Environmental Engineering, CEE6510 - Numerical Methods in Civil Engineering, Spring 2006, "Solving selected equations and systems of equations in hydraulics using Matlab", August/September 2004, \url{http://ocw.usu.edu/Civil_and_Environmental_Engineering/Numerical_Methods_in_Civil_Engineering/}.
 #'    \item Tyler G. Hicks, P.E., \emph{Civil Engineering Formulas: Pocket Guide}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2002, page 423, 425.
 #'    \item Wikimedia Foundation, Inc. Wikipedia, 26 November 2015, “Manning formula”, \url{https://en.wikipedia.org/wiki/Manning_formula}.
 #'    \item John C. Crittenden, R. Rhodes Trussell, David W. Hand, Kerry J. Howe, George Tchobanoglous, \emph{MWH's Water Treatment: Principles and Design}, Third Edition, Hoboken, New Jersey: John Wiley & Sons, Inc., 2012, page 1861-1862.
 #'    \item Andrew Chadwick, John Morfett and Martin Borthwick, \emph{Hydraulics in Civil and Environmental Engineering}, Fourth Edition, New York City, New York: Spon Press, Inc., 2004, page 133.
+#'    \item Robert L. Mott and Joseph A. Untener, \emph{Applied Fluid Mechanics}, Seventh Edition, New York City, New York: Pearson, 2015, page 376, 377-378, 392.
+#'    \item Wikimedia Foundation, Inc. Wikipedia, 5 May 2016, “Gravitational acceleration”, \url{https://en.wikipedia.org/wiki/Gravitational_acceleration}.
+#'    \item Wikimedia Foundation, Inc. Wikipedia, 29 May 2016, “Conversion of units”, \url{https://en.wikipedia.org/wiki/Conversion_of_units}.
 #' }
 #'
 #' @encoding UTF-8
@@ -201,9 +227,32 @@
 #' @examples
 #' library(iemisc)
 #' library(iemiscdata)
+#'
+#' # Practice Problem 14.12 from Mott (page 392)
+#' y <- Manningcircy(y_d = 0.5, d = 6, units = "Eng")
+#'
+#' # See npartfull in iemiscdata for the Manning's n table that the
+#' # following example uses
+#' # Use the normal Manning's n value for 1) Corrugated Metal, 2) Stormdrain.
+#' data(npartfull)
+#'
+#' # We are using the culvert as a stormdrain in this problem
+#' nlocation <- grep("Stormdrain",
+#' npartfull$"Type of Conduit and Description")
+#' n <- npartfull[nlocation, 3] # 3 for column 3 - Normal n
+#'
+#' Manningcirc(d = 6, Sf = 1 / 500, n = n, y = y$y, units = "Eng")
+#' # d = 6 ft, Sf = 1 / 500 ft/ft, n = 0.024, y = 3 ft, units = "Eng"
+#' # This will solve for Q since it is missing and Q will be in ft^3/s
+#'
+#'
+#'
 #' # Example Problem 14.2 from Mott (page 377-378)
 #' y <- Manningcircy(y_d = 0.5, d = 200/1000, units = "SI")
 #'
+#' # See npartfull in iemiscdata for the Manning's n table that the
+#' # following example uses
+#' # Use the normal Manning's n value for 1) Clay, 2) Common drainage tile.
 #' data(npartfull)
 #' nlocation <- grep("Common drainage tile",
 #' npartfull$"Type of Conduit and Description")
@@ -223,14 +272,10 @@
 #'
 #'
 #'
-#'
 #' # Modified Exercise 4.1 from Sturm (page 153)
-#' Manningcircy(Q = 15, Sf = 0.002, d = 36/12, units = "Eng")
-#' # Q = 15 cfs, Sf = 0.002 ft/ft, n = 0.015, d = 36/12 ft, units = English units
-#' # This will solve for y since it is missing and y will be in ft
-#'
-#' # C. Modified Exercise 4.1 from Sturm (page 153)
-#' # See \code{\link[iemiscdata]{nchannel}} for the Manning's n table that the
+#' # Note: The Q in Exercise 4.1 is actually found using the Chezy equation,
+#' # this is a modification of that problem
+#' # See nchannel in iemiscdata for the Manning's n table that the
 #' # following example uses
 #' # Use the normal Manning's n value for 1) Natural streams - minor streams
 #' # (top width at floodstage < 100 ft), 2) Mountain streams, no vegetation
@@ -245,7 +290,9 @@
 #' # Sf = 0.002 ft/ft, n = 0.04, y = 1.6 ft, d = 2 ft, units = English units
 #' # This will solve for Q since it is missing and Q will be in ft^3/s
 #'
-#' # D. Modified Exercise 4.5 from Sturm (page 154)
+#'
+#'
+#' # Modified Exercise 4.5 from Sturm (page 154)
 #' library(NISTunits)
 #' ysi <- NISTftTOmeter(y$y)
 #' dsi <- NISTftTOmeter(2)
@@ -253,6 +300,9 @@
 #' # Sf = 0.022 m/m, n = 0.023, y = 0.48768 m, d = 0.6096 m, units = SI units
 #' # This will solve for Q since it is missing and Q will be in m^3/s
 #'
+#' @importFrom pracma interp1
+#' @import data.table
+#'
 #' @name Manningcirc
 NULL
 
@@ -280,7 +330,9 @@ stop("Either Q, n, Sf, y, or d is 0. None of the variables can be 0. Try again."
 if (units == "SI") {
 
    k <- 1
-   
+
+   g <- 9.80665 # m / s^2
+
    T <- ifelse(is.null(T), 20, T) # degrees C
 
    rho = (999.83952 + 16.945176 * T - 7.9870401 * 10 ^ -3 * T ^ 2 - 46.170461 * 10 ^ -6 * T ^ 3 + 105.56302 * 10 ^ -9 * T ^ 4 - 280.54253 * 10 ^ -12 * T ^ 5) / (1 + 16.879850 * 10 ^ -3 * T) # kg / m ^ 3 as density
@@ -288,37 +340,37 @@ if (units == "SI") {
    if (between(T, 0, 20, incbounds = FALSE)) {
 
    A <- (1301 / (998.333 + 8.1855 * (T - 20) + 0.00585 * (T - 20) ^ 2)) - 1.30223
-   
+
    mu <- 10 ^ -3 * 10 ^ A # * 10 ^ -3 kg / m * s as dynamic viscosity
 
    } else if (between(T, 20, 100, incbounds = FALSE)) {
-   
+
    B <- (1.3272 * (20 - T) - 0.001053 * (T - 20) ^ 2) / (T + 105)
 
    mu <- (1.002 * 10 ^ -3) * (10 ^ B) # * 10 ^ -3 kg / m * s as dynamic viscosity
-   
+
    } else if (T == 0) {
-   
+
    mu <- 1.781 # * 10 ^ -3 kg / m * s as dynamic viscosity
- 
+
    } else if (T == 20) {
-   
+
    mu <- 1.002 # * 10 ^ -3 kg / m * s as dynamic viscosity
 
    } else if (T == 100) {
-   
-   mu <- 0.282 # * 10 ^ -3 kg / m * s as dynamic viscosity
-   
+
+   mu <-  0.282 # * 10 ^ -3 kg / m * s as dynamic viscosity
+
    }
-   
+
 } else if (units == "Eng") {
 
    k <- 3.2808399 ^ (1 / 3)
 
-   T <- 32
-   
+   g <- 9.80665 * (3937 / 1200) # ft / sec^2
+
    T <- ifelse(is.null(T), 68, T) # degrees F
-  
+
   x <- c(32, 49, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180, 190, 200, 212)
   y1 <- c(1.94, 1.94, 1.94, 1.938, 1.936, 1.934, 1.931, 1.927, 1.923, 1.918, 1.913, 1.908, 1.902, 1.896, 1.89, 1.883, 1.876, 1.868, 1.86)
   y2 <- c(3.746, 3.229, 2.735, 2.359, 2.05, 1.799, 1.595, 1.424, 1.284, 1.168, 1.069, 0.981, 0.905, 0.838, 0.78, 0.726, 0.678, 0.637, 0.593)
@@ -340,8 +392,13 @@ A <- (theta - sin(theta)) * (d ^ 2 / 8)
 P <- ((theta * d) / 2)
 B <- d * sin(theta / 2)
 R <- A / P
+D <- A / B
 
-Q <- (k / n) * (A ^ (5 / 3)) / (P ^ (2 / 3)) * sqrt(Sf)
+Qfun <- function(Q) {Q - ((((theta - sin(theta)) * (d ^ 2 / 8)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((theta * d) / 2) ^ (2 / 3))}
+
+Quse <- uniroot(Qfun, interval = c(0.0000001, 200), extendInt = "yes")
+
+Q <- Quse$root
 
 V <- Q / A
 
@@ -349,15 +406,31 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(Q = Q, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(Q = Q, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
 
 
 } else if (missing(n)) {
@@ -367,8 +440,13 @@ A <- (theta - sin(theta)) * (d ^ 2 / 8)
 P <- ((theta * d) / 2)
 B <- d * sin(theta / 2)
 R <- A / P
+D <- A / B
 
-n <- (k / Q) * (A ^ (5 / 3)) / (P ^ (2 / 3)) * sqrt(Sf)
+nfun <- function(n) {Q - ((((theta - sin(theta)) * (d ^ 2 / 8)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((theta * d) / 2) ^ (2 / 3))}
+
+nuse <- uniroot(nfun, interval = c(0.0000001, 200), extendInt = "yes")
+
+n <- nuse$root
 
 V <- Q / A
 
@@ -376,15 +454,32 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(n = n, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(n = n, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
+
 
 } else if (missing(Sf)) {
 
@@ -393,8 +488,13 @@ A <- (theta - sin(theta)) * (d ^ 2 / 8)
 P <- ((theta * d) / 2)
 B <- d * sin(theta / 2)
 R <- A / P
+D <- A / B
 
-Sf <- (Q / ((k / n) * (A ^ (5 / 3)) / (P ^ (2 / 3)))) ^ 2
+Sffun <- function(Sf) {Q - ((((theta - sin(theta)) * (d ^ 2 / 8)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((theta * d) / 2) ^ (2 / 3))}
+
+Sfuse <- uniroot(Sffun, interval = c(0.0000001, 200), extendInt = "yes")
+
+Sf <- Sfuse$root
 
 V <- Q / A
 
@@ -402,15 +502,31 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(Sf = Sf, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(Sf = Sf, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
 }
 }
 }
@@ -471,7 +587,7 @@ rh <- (n * Q) / (k * sqrt(Sf))
 
 thetafun <- function (theta) ((theta - sin(theta)) * (d ^ 2 / 8)) * (((theta - sin(theta)) * (d ^ 2 / 8) / ((theta * d) / 2)) ^ (2 / 3)) - rh
 
-thetause <- uniroot(thetafun, c(-1000, 1000))
+thetause <- uniroot(thetafun, c(-1000, 1000), extendInt = "yes")
 theta <- thetause$root
 
 y <- (d / 2) * (1 - cos(theta / 2))
