@@ -1,7 +1,8 @@
 #' Triangular cross-section for the Gauckler-Manning-Strickler equation
 #'
 #' This function solves for one missing variable in the Gauckler-Manning-
-#' Strickler equation for a triangular cross-section and uniform flow.
+#' Strickler equation for a triangular cross-section and uniform flow. The
+#' \code{\link[stats]{uniroot}} function is used to obtain the missing parameter.
 #'
 #' Gauckler-Manning-Strickler equation is expressed as
 #'
@@ -80,13 +81,22 @@
 #'
 #'
 #'
+#' \deqn{D = \frac{A}{B}}
+#'
+#' \describe{
+#'	\item{\emph{D}}{the hydraulic depth (m or ft)}
+#'	\item{\emph{A}}{the cross-sectional area (m^2 or ft^2)}
+#'	\item{\emph{B}}{the top width of the channel (m or ft)}
+#' }
+#'
+#'
 #' A rough turbulent zone check is performed on the water flowing in the
 #' channel using the Reynolds number (Re). The Re equation follows:
 #'
 #' \deqn{Re = \frac{\rho RV}{\mu}}
 #'
 #' \describe{
-#'	\item{\emph{Re}}{the velocity (m/s or ft/s)}
+#'	\item{\emph{Re}}{Reynolds number (dimensionless)}
 #'	\item{\emph{\eqn{\rho}}}{density (kg/m^3 or slug/ft^3)}
 #'	\item{\emph{R}}{the hydraulic radius (m or ft)}
 #'	\item{\emph{V}}{the velocity (m/s or ft/s)}
@@ -95,6 +105,20 @@
 #'
 #'
 #'
+#' A critical flow check is performed on the water flowing in the channel
+#' using the Froude number (Fr). The Fr equation follows:
+#'
+#' \deqn{Fr = \frac{V}{\left(\sqrt{g * D}\right)}}
+#'
+#' \describe{
+#'	\item{\emph{Fr}}{the Froude number (dimensionless)}
+#'	\item{\emph{V}}{the velocity (m/s or ft/s)}
+#'	\item{\emph{g}}{gravitational acceleration (m/s^2 or ft/sec^2)}
+#'	\item{\emph{D}}{the hydraulic depth (m or ft)}
+#' }
+#'
+#'
+#'
 #' @note
 #' Assumptions: uniform flow, prismatic channel, and surface water temperature
 #' of 20 degrees Celsius (68 degrees Fahrenheit) at atmospheric pressure
@@ -121,8 +145,8 @@
 #'   the United Kingdom)]
 #'
 #' @return the missing parameter (Q, n, m, Sf, or y) & area (A), wetted
-#'   perimeter (P), velocity (V), top width (B), R (hydraulic radius), and Re
-#'   (Reynolds number) as a \code{\link[base]{list}}.
+#'   perimeter (P), velocity (V), top width (B), R (hydraulic radius), Re
+#'   (Reynolds number), and Fr (Froude number) as a \code{\link[base]{list}}.
 #'
 #'
 #' @source
@@ -131,13 +155,16 @@
 #'
 #' @references
 #' \enumerate{
-#'    \item Terry W. Sturm, \emph{Open Channel Hydraulics}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2010, page 8, 36, 102, 120, 153-154.
+#'    \item Terry W. Sturm, \emph{Open Channel Hydraulics}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2010, page 2, 8, 36, 102, 120, 153-154.
 #'    \item Dan Moore, P.E., NRCS Water Quality and Quantity Technology Development Team, Portland Oregon, "Using Mannings Equation with Natural Streams", August 2011, \url{http://www.wcc.nrcs.usda.gov/ftpref/wntsc/H&H/xsec/manningsNaturally.pdf}.
 #'    \item Gilberto E. Urroz, Utah State University Civil and Environmental Engineering, CEE6510 - Numerical Methods in Civil Engineering, Spring 2006, "Solving selected equations and systems of equations in hydraulics using Matlab", August/September 2004, \url{http://ocw.usu.edu/Civil_and_Environmental_Engineering/Numerical_Methods_in_Civil_Engineering/}.
 #'    \item Tyler G. Hicks, P.E., \emph{Civil Engineering Formulas: Pocket Guide}, 2nd Edition, New York City, New York: The McGraw-Hill Companies, Inc., 2002, page 423, 425.
 #'    \item Wikimedia Foundation, Inc. Wikipedia, 26 November 2015, “Manning formula”, \url{https://en.wikipedia.org/wiki/Manning_formula}.
 #'    \item John C. Crittenden, R. Rhodes Trussell, David W. Hand, Kerry J. Howe, George Tchobanoglous, \emph{MWH's Water Treatment: Principles and Design}, Third Edition, Hoboken, New Jersey: John Wiley & Sons, Inc., 2012, page 1861-1862.
 #'    \item Andrew Chadwick, John Morfett and Martin Borthwick, \emph{Hydraulics in Civil and Environmental Engineering}, Fourth Edition, New York City, New York: Spon Press, Inc., 2004, page 133.
+#'    \item Robert L. Mott and Joseph A. Untener, \emph{Applied Fluid Mechanics}, Seventh Edition, New York City, New York: Pearson, 2015, page 376, 393.
+#'    \item Wikimedia Foundation, Inc. Wikipedia, 5 May 2016, “Gravitational acceleration”, \url{https://en.wikipedia.org/wiki/Gravitational_acceleration}.
+#'    \item Wikimedia Foundation, Inc. Wikipedia, 29 May 2016, “Conversion of units”, \url{https://en.wikipedia.org/wiki/Conversion_of_units}.
 #' }
 #'
 #' @encoding UTF-8
@@ -155,26 +182,28 @@
 #' @examples
 #' library(iemisc)
 #' library(iemiscdata)
+#' # Practice Problem 14.41 from Mott (page 393)
+#' # See nchannel in iemiscdata for the Manning's n table that the
+#' # following example uses
+#' # Use the normal Manning's n value for 1) Natural streams - minor streams
+#' # (top width at floodstage < 100 ft), 2) Excavated or Dredged Channels, 3)
+#' # Earth, straight, and uniform, 4) clean, recently completed.
+#' data(nchannel)
+#'
+#' nlocation <- grep("clean, recently completed",
+#' nchannel$"Type of Channel and Description")
+#' n <- nchannel[nlocation, 3] # 3 for column 3 - Normal n
+#' Manningtri(Q = 0.68, m = 1.5, Sf = 0.0023, n = n, units = "Eng")
+#' # Q = 0.68 cfs, m = 1.5, Sf = 0.002 ft/ft, n = 0.05, units = English units
+#' # This will solve for y since it is missing and y will be in ft
+#'
+#'
+#'
 #' # Modified Exercise 4.1 from Sturm (page 153)
 #' Manningtri(Q = 3000, m = 3, Sf = 0.002, n = 0.025, units = "Eng")
 #' # Q = 3000 cfs, m = 3, Sf = 0.002 ft/ft, n = 0.025, units = English units
 #' # This will solve for y since it is missing and y will be in ft
 #'
-#' # Modified Exercise 4.1 from Sturm (page 153)
-#' # See \code{\link[iemiscdata]{nchannel}} for the Manning's n table that the
-#' # following example uses
-#' # Use the maximum Manning's n value for 1) Natural streams - minor streams
-#' # (top width at floodstage < 100 ft), 2) Mountain streams, no vegetation
-#' # in channel, banks usually steep, trees and brush along banks submerged at
-#' # high stages and 3) bottom: gravels, cobbles, and few boulders.
-#' data(nchannel)
-#'
-#' nlocation <- grep("bottom: gravels, cobbles, and few boulders",
-#' nchannel$"Type of Channel and Description")
-#' n <- nchannel[nlocation, 4] # 4 for column 4 - Maximum n
-#' Manningtri(Q = 3000, m = 3, Sf = 0.002, n = n, units = "Eng")
-#' # Q = 3000 cfs, m = 3, Sf = 0.002 ft/ft, n = 0.05, units = English units
-#' # This will solve for y since it is missing and y will be in ft
 #'
 #'
 #' # Modified Exercise 4.5 from Sturm (page 154)
@@ -182,6 +211,8 @@
 #' # Q = 950 m^3/s, m = 2, Sf = 0.022 m/m, n = 0.023, units = SI units
 #' # This will solve for y since it is missing and y will be in m
 #'
+#' @importFrom pracma interp1
+#' @import data.table
 #'
 #' @export
 Manningtri <- function (Q = NULL, n = NULL, m = NULL, Sf = NULL, y = NULL, T = NULL, units = c("SI", "Eng")) {
@@ -206,7 +237,9 @@ stop("Either Q, n, m, Sf, or y is 0. None of the variables can be 0. Try again."
 if (units == "SI") {
 
    k <- 1
-   
+
+   g <- 9.80665 # m / s^2
+
    T <- ifelse(is.null(T), 20, T) # degrees C
 
    rho = (999.83952 + 16.945176 * T - 7.9870401 * 10 ^ -3 * T ^ 2 - 46.170461 * 10 ^ -6 * T ^ 3 + 105.56302 * 10 ^ -9 * T ^ 4 - 280.54253 * 10 ^ -12 * T ^ 5) / (1 + 16.879850 * 10 ^ -3 * T) # kg / m ^ 3 as density
@@ -214,37 +247,37 @@ if (units == "SI") {
    if (between(T, 0, 20, incbounds = FALSE)) {
 
    A <- (1301 / (998.333 + 8.1855 * (T - 20) + 0.00585 * (T - 20) ^ 2)) - 1.30223
-   
+
    mu <- 10 ^ -3 * 10 ^ A # * 10 ^ -3 kg / m * s as dynamic viscosity
 
    } else if (between(T, 20, 100, incbounds = FALSE)) {
-   
+
    B <- (1.3272 * (20 - T) - 0.001053 * (T - 20) ^ 2) / (T + 105)
 
    mu <- (1.002 * 10 ^ -3) * (10 ^ B) # * 10 ^ -3 kg / m * s as dynamic viscosity
-   
+
    } else if (T == 0) {
-   
+
    mu <- 1.781 # * 10 ^ -3 kg / m * s as dynamic viscosity
- 
+
    } else if (T == 20) {
-   
+
    mu <- 1.002 # * 10 ^ -3 kg / m * s as dynamic viscosity
 
    } else if (T == 100) {
-   
-   mu <- 0.282 # * 10 ^ -3 kg / m * s as dynamic viscosity
-   
+
+   mu <-  0.282 # * 10 ^ -3 kg / m * s as dynamic viscosity
+
    }
-   
+
 } else if (units == "Eng") {
 
    k <- 3.2808399 ^ (1 / 3)
 
-   T <- 32
-   
+   g <- 9.80665 * (3937 / 1200) # ft / sec^2
+
    T <- ifelse(is.null(T), 68, T) # degrees F
-  
+
   x <- c(32, 49, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180, 190, 200, 212)
   y1 <- c(1.94, 1.94, 1.94, 1.938, 1.936, 1.934, 1.931, 1.927, 1.923, 1.918, 1.913, 1.908, 1.902, 1.896, 1.89, 1.883, 1.876, 1.868, 1.86)
   y2 <- c(3.746, 3.229, 2.735, 2.359, 2.05, 1.799, 1.595, 1.424, 1.284, 1.168, 1.069, 0.981, 0.905, 0.838, 0.78, 0.726, 0.678, 0.637, 0.593)
@@ -265,8 +298,13 @@ A <- m * y ^ 2
 P <- 2 * y * sqrt(1 + m ^ 2)
 B <- 2 * m * y
 R <- A / P
+D <- A / B
 
-Q <- (k / n) * (A ^ (5 / 3)) / (P ^ (2 / 3)) * sqrt(Sf)
+Qfun <- function(Q) {Q - ((((m * y ^ 2)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((2 * y * sqrt(1 + m ^ 2))) ^ (2 / 3))}
+
+Quse <- uniroot(Qfun, interval = c(0.0000001, 200), extendInt = "yes")
+
+Q <- Quse$root
 
 V <- Q / A
 
@@ -274,15 +312,31 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(Q = Q, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(Q = Q, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
 
 
 } else if (missing(n)) {
@@ -291,8 +345,13 @@ A <- m * y ^ 2
 P <- 2 * y * sqrt(1 + m ^ 2)
 B <- 2 * m * y
 R <- A / P
+D <- A / B
 
-n <- (k / Q) * (A ^ (5 / 3)) / (P ^ (2 / 3)) * sqrt(Sf)
+nfun <- function(n) {Q - ((((m * y ^ 2)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((2 * y * sqrt(1 + m ^ 2))) ^ (2 / 3))}
+
+nuse <- uniroot(nfun, interval = c(0.0000001, 200), extendInt = "yes")
+
+n <- nuse$root
 
 V <- Q / A
 
@@ -300,21 +359,38 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(n = n, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(n = n, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
+
 
 } else if (missing(m)) {
 
 mfun <- function(m) {Q - ((((m * y ^ 2)) ^ (5 / 3) * sqrt(Sf) * (k / n)) / ((2 * y * sqrt(1 + m ^ 2))) ^ (2 / 3))}
 
-muse <- uniroot(mfun, interval = c(0, 30))
+muse <- uniroot(mfun, interval = c(0, 30), extendInt = "yes")
 
 m <- muse$root
 
@@ -322,6 +398,7 @@ A <- m * y ^ 2
 P <- 2 * y * sqrt(1 + m ^ 2)
 B <- 2 * m * y
 R <- A / P
+D <- A / B
 
 V <- Q / A
 
@@ -329,21 +406,38 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(m = m, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(m = m, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
+
 
 } else if (missing(y)) {
 
 yfun <- function(y) {Q - ((((m * y ^ 2)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((2 * y * sqrt(1 + m ^ 2))) ^ (2 / 3))}
 
-yuse <- uniroot(yfun, interval = c(1, 100))
+yuse <- uniroot(yfun, interval = c(0.0000001, 200), extendInt = "yes")
 
 y <- yuse$root
 
@@ -351,6 +445,7 @@ A <- m * y ^ 2
 P <- 2 * y * sqrt(1 + m ^ 2)
 B <- 2 * m * y
 R <- A / P
+D <- A / B
 
 V <- Q / A
 
@@ -358,15 +453,32 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(y = y, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(y = y, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
+
 
 } else if (missing(Sf)) {
 
@@ -374,8 +486,13 @@ A <- m * y ^ 2
 P <- 2 * y * sqrt(1 + m ^ 2)
 B <- 2 * m * y
 R <- A / P
+D <- A / B
 
-Sf <- (Q / ((k / n) * (A ^ (5 / 3)) / (P ^ (2 / 3)))) ^ 2
+Sffun <- function(Sf) {Q - ((((m * y ^ 2)) ^ (5 / 3) * sqrt(Sf)) * (k / n) / ((2 * y * sqrt(1 + m ^ 2))) ^ (2 / 3))}
+
+Sfuse <- uniroot(Sffun, interval = c(0.0000001, 200), extendInt = "yes")
+
+Sf <- Sfuse$root
 
 V <- Q / A
 
@@ -383,15 +500,31 @@ Re <- (rho * R * V) / mu
 
 if (Re > 2000) {
 
-cat("\nFlow is in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
+cat("\nFlow IS in the rough turbulent zone so the Gauckler-Manning-Strickler equation is acceptable to use.\n\n")
 
 } else {
 
-cat("\nFlow is not in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
+cat("\nFlow is NOT in the rough turbulent zone so the Gauckler-Manning-Strickler equation is not acceptable to use.\n\n")
 
 }
 
-return(list(Sf = Sf, V = V, A = A, P = P, B = B, R = R, Re = Re))
+Fr <- V / (sqrt(g * D))
+
+if (Fr == 1) {
+
+cat("\nThis is critical flow.\n\n")
+
+} else if (Fr < 1) {
+
+cat("\nThis is subcritical flow.\n\n")
+
+} else if (Fr > 1) {
+
+cat("\nThis is supercritical flow.\n\n")
+
+}
+
+return(list(Sf = Sf, V = V, A = A, P = P, R = R, Re = Re, Fr = Fr))
 }
 }
 }
